#
# spec file for package ghc-mwc-random
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name mwc-random
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.15.1.0
Release:        bp160.1.7
Summary:        Fast, high quality pseudo random number generation
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-math-functions-devel
BuildRequires:  ghc-math-functions-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-doctest-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This package contains code for generating high quality random numbers that
follow either a uniform or normal distribution. The generated numbers are
suitable for use in statistical applications. . The uniform PRNG uses
Marsaglia's MWC256 (also known as MWC8222) multiply-with-carry generator, which
has a period of 2^8222 and fares well in tests of randomness. It is also
extremely fast, between 2 and 3 times faster than the Mersenne Twister.
. Compared to the mersenne-random package, this package has a more convenient
API, is faster, and supports more statistical distributions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md docs

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jul  9 2024 Peter Simons <psimons@suse.com>
- Update mwc-random to version 0.15.1.0.
  [#]# Changes in 0.15.1.0
  * Additon of binomial sampler using the rejection sampling method in
    Kachitvichyanukul, V. and Schmeiser, B. W.  Binomial Random
    Variate Generation.  Communications of the ACM, 31, 2 (February,
    1988) 216. <https://dl.acm.org/doi/pdf/10.1145/42372.42381>. A more
    efficient basis for e.g. the beta binomial distribution:
  `beta a b g >>= \p -> binomial n p g`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Nov 15 2021 psimons@suse.com
- Update mwc-random to version 0.15.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug 16 2021 psimons@suse.com
- Update mwc-random to version 0.15.0.2.
  [#]# Changes in 0.15.0.2
  * Doctests on 32-bit platforms are fixed. (#79)
* Sat Jul 10 2021 psimons@suse.com
- Update mwc-random to version 0.15.0.1 revision 2.
  [#]# Changes in 0.15.0.1
  * Bug in generation of Int/Word in both uniform and uniformR is fixed. (#75)
  [#]# Changes in 0.15.0.0
  * `withSystemRandomST` and `createSystemSeed` are added.
  * `withSystemRandom` is deprecated.
  * `random>=1.2` is dependency of `mwc-random`.
  * Instances for type classes `StatefulGen` & `FrozenGen` defined in random-1.2
    are added for `Gen`.
  * Functions in `System.Random.MWC.Distributions` and
    `System.Random.MWC.CondensedTable` now work with arbitrary `StatefulGen`
  * `System.Random.MWC.uniformVector` now works with arbitrary `StatefulGen` as
    well and uses in-place initialization instead of `generateM`. It should be
    faster for anything but IO and ST (those shoud remain same).
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Fri Aug 17 2018 psimons@suse.com
- Update mwc-random to version 0.14.0.0.
  [#]# Changes in 0.14.0.0
  * Low level functions for acquiring random data for initialization
    of PRGN state is moved to `System.Random.MWC.SeedSource` module
  * Ensure that carry is always correct when restoring PRNG state from
    seed. Only affects users who create 258 element seed manually.
    (#63, #65)
* Fri Jul 20 2018 psimons@suse.com
- Add mwc-random at version 0.13.6.0.
